/**
 *  Exemple d'utilisation de la bibliothque digital_filter
 *
 *  Auteur : Ferdinand Piette (Avril 2011)
 *  Version : 1.0b
 *
 *  On a 32 chantillons d'un signal compos d'une somme de deux sinusoides.
 *  La premire sinusode a pour frquence  250Hz  et pour amplitude 1.
 *  La seconde sinusode a pour frquence 1500Hz et pour amplitude 0.5
 *  La frquence d'chantillonnage est 4000Hz
 *
 *  Le filtre appliqu est un filtre passe bas ayant pour caractristique :
 *      - attnuation en bande passante < 2dB
 *      - attnuationen bande coup > 20dB
 *      - bande passante jusque 500Hz
 *      - bande coup  partir de 1000Hz
 *
 *  La fonction de transfert d'un tel filtre RII est :
 *
 *          0.0408*z + 0.1224*z^-1 + 0.1224*z^-2 + 0.0408*z^-3
 *  H(z) = ----------------------------------------------------
 *             1 - 1.2978*z^-1 + 0.7875*z^-2 - 0.1632*z^-3
 */

#include <stdio.h>
#include <stdlib.h>
#include "digital_filter.h"

int main()
{
    int i;
    double coef_b[4] = {0.0408, 0.1224, 0.1224, 0.0408};    // Les 4 coefficients ai
    double coef_a[3] = {-1.2978, 0.7875, -0.1632};          // Les 3 coefficients bj
    double echantillons[32] = {0.7362, 0.2071, 1.2774, 1., 0.5703, 1.2071, 0.0291, 0., -0.0291, -1.2071, -0.5703, -1.0, -1.2774, -0.2071, -0.7362, 0.
                               0.7362, 0.2071, 1.2774, 1., 0.5703, 1.2071, 0.0291, 0., -0.0291, -1.2071, -0.5703, -1.0, -1.2774, -0.2071, -0.7362, 0.};
    digital_filter mon_filtre;

    init_digital_filter(&mon_filtre, coef_a, 4, coef_b, 3); // Initialisation du filtre avec les coefficients de la fonction de transfert

    for(i = 0; i < 32; i++) // On filtre les chantillons
        printf("Echantillon numero %d : %lf\t | Apres filtrage : %lf\n", i, echantillons[i], filter_next_sample(&mon_filtre, echantillons[i]));


    return 0;
}
